# eric7.CondaInterface.CondaExportDialog

Module implementing a dialog to generate a requirements file for conda.

### Global Attributes

None

### Classes

CondaExportDialog | Class implementing a dialog to generate a requirements file for conda.

### Functions

None

## CondaExportDialog

Class implementing a dialog to generate a requirements file for conda.

### Derived from

QDialog, Ui_CondaExportDialog

### Class Attributes

None

### Class Methods

None

### Methods

CondaExportDialog | Constructor
__refresh | Private slot to refresh the displayed list.
__updateButtons | Private method to set the state of the various buttons.
__writeToFile | Private method to write the requirements text to a file.
closeEvent | Protected slot implementing a close event handler.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
on_copyButton_clicked | Private slot to copy the requirements text to the clipboard.
on_insertButton_clicked | Private slot to insert the requirements text at the cursor position of the current editor.
on_replaceAllButton_clicked | Private slot to replace the text of the current editor with the requirements text.
on_replaceSelectionButton_clicked | Private slot to replace the selected text of the current editor with the requirements text.
on_requirementsEdit_textChanged | Private slot handling changes of the requirements text.
on_requirementsFilePicker_textChanged | Private slot handling a change of the requirements file name.
on_saveButton_clicked | Private slot to save the requirements text to the requirements file.
on_saveToButton_clicked | Private slot to write the requirements text to a new file.
start | Public method to start the command.

### Static Methods

None

#### CondaExportDialog (Constructor)

CondaExportDialog(conda, envName, envPrefix, parent=None)

Constructor

conda (Conda)
  reference to the conda interface object
envName (str)
  name of the environment to create the requirements file from
envPrefix (str)
  prefix of the environment to create the requirements file from
parent (QWidget)
  reference to the parent widget

#### CondaExportDialog.__refresh

__refresh()

Private slot to refresh the displayed list.

#### CondaExportDialog.__updateButtons

__updateButtons()

Private method to set the state of the various buttons.

#### CondaExportDialog.__writeToFile

__writeToFile(fileName)

Private method to write the requirements text to a file.

fileName (str)
  name of the file to write to

#### CondaExportDialog.closeEvent

closeEvent(e)

Protected slot implementing a close event handler.

e (QCloseEvent)
  close event

#### CondaExportDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button (QAbstractButton)
  button that was clicked

#### CondaExportDialog.on_copyButton_clicked

on_copyButton_clicked()

Private slot to copy the requirements text to the clipboard.

#### CondaExportDialog.on_insertButton_clicked

on_insertButton_clicked()

Private slot to insert the requirements text at the cursor position of the current editor.

#### CondaExportDialog.on_replaceAllButton_clicked

on_replaceAllButton_clicked()

Private slot to replace the text of the current editor with the requirements text.

#### CondaExportDialog.on_replaceSelectionButton_clicked

on_replaceSelectionButton_clicked()

Private slot to replace the selected text of the current editor with the requirements text.

#### CondaExportDialog.on_requirementsEdit_textChanged

on_requirementsEdit_textChanged()

Private slot handling changes of the requirements text.

#### CondaExportDialog.on_requirementsFilePicker_textChanged

on_requirementsFilePicker_textChanged(txt)

Private slot handling a change of the requirements file name.

txt (str)
  name of the requirements file

#### CondaExportDialog.on_saveButton_clicked

on_saveButton_clicked()

Private slot to save the requirements text to the requirements file.

#### CondaExportDialog.on_saveToButton_clicked

on_saveToButton_clicked()

Private slot to write the requirements text to a new file.

#### CondaExportDialog.start

start()

Public method to start the command.

Up